pub struct TensorIterElement {
pub indices: ArrayUsize8,
pub offset: usize,
}Expand description
Thread-safe element reference for parallel iteration
Fields
indices: ArrayUsize8Indices of the element
offset: usizeOffset in bytes from the tensor’s base pointer
Implementations
Sourceimpl TensorIterElement
impl TensorIterElement
Sourcepub unsafe fn as_ptr(&self, base_ptr: *const u8) -> *const u8
pub unsafe fn as_ptr(&self, base_ptr: *const u8) -> *const u8
Get a pointer to the element data given the tensor’s base pointer
Safety
The caller must ensure that:
- The base_ptr is valid and points to the tensor’s data
- The offset is within the tensor’s bounds
- The returned pointer is used safely
Sourcepub unsafe fn as_mut_ptr(&self, base_ptr: *mut u8) -> *mut u8
pub unsafe fn as_mut_ptr(&self, base_ptr: *mut u8) -> *mut u8
Get a mutable pointer to the element data given the tensor’s base pointer
Safety
The caller must ensure that:
- The base_ptr is valid and points to the tensor’s data
- The offset is within the tensor’s bounds
- The returned pointer is used safely
- No other references to this data exist